
% MATALAB source code for analysis of cell proteomic footprints
%
% RUN this script.
% When the dialog window opens, select the footprint file 'aligned_footprints.mat' to load matrix with footprints into the workspace.
% Marix contains the binary encoded aligned footprints (46 footprints with 1967 rows).
% 
% Matrix columns:
%	Footprints of Cancer cells (Ref.1):
%		1	Untreated F-7 cells  (ATCC)
%		2	Untreated HepG2 cells (ATCC)
%		3	MCF-7 cells treated with doxorubicin (IC96)
%		4	MCF 7 cells treated with tamoxifen (IC96)
%		5	MCF 7 cells treated with etoposide (IC50)
%		6	MCF 7 cells treated with etoposide (IC50 twice)
%		7	MCF 7 cells treated with etoposide (IC96)
%		8	MCF 7 cells treated with etoposide (IC96 twice)
%		9	Control (trypsin+HBSS) 
%	Footprints of Endothelial cells (Ref.2):	
%		10	HMEC stimulated by HepG2 (donor 1)
%		11	HMEC stimulated by HepG2 (donor 2)
%		12	HMEC stimulated by LNcaP (donor 1)
%		13	HMEC stimulated by LNcaP (donor 2)
%		14	HMEC stimulated by MCF-7 (donor 1)
%		15	HMEC stimulated by MCF-7 (donor 2)
%		16	HMEC stimulated by growth factors
%		17	HMEC stimulated by growth factors
%		18	Control (Fibroblasts) 
%	Footprints of Fibroblasts (Ref.3):	
%		19	Fibroblasts from adipose tissue
%		20	Fibroblasts from adipose tissue
%		21	Fibroblasts from adipose tissue
%		22	Fibroblasts from adipose tissue
%		23	Fibroblasts from skin
%		24	Fibroblasts from skin
%		25	Fibroblasts from skin
%		26	Fibroblasts from skin
%		27	Fibroblasts from fetal skin
%		28	Fibroblasts from fetal skin
%		29	Fibroblasts from the dermal papilla
%		30	Fibroblasts from the dermal papilla
%		31	Fibroblasts from the dermal papilla
%		32	Fibroblasts from the dermal papilla
%		33	Fibroblasts from the dermal papilla
%		34	Fibroblasts from the dermal papilla
%		35	Fibroblasts from the dermal papilla
%		36	Fibroblasts from the dermal papilla
%		37	Fibroblasts from the dermal papilla
%		38	Fibroblasts from the dermal papilla
%		39	Fibroblasts from the dermal papilla
%		40	Fibroblasts from the dermal papilla
%		41	Fibroblasts from the dermal papilla
%		42	Fibroblasts from the dermal papilla
%		43	Fibroblasts from the dermal papilla
%		44	Fibroblasts from the dermal papilla
%		45	Fibroblasts from the dermal papilla
%		46	Fibroblasts from the dermal papilla

% Ref.1 Mol. Cell. Proteomics 2012, 11, M111.014480-M111.014480, doi:10.1074/mcp.M111.014480
% Ref.2: Hum. Vaccin. Immunother. 2013, 9, 198209, doi:10.4161/hv.22828
% Ref.3: Rapid Commun. Mass Spectrom. 2009, 23, 680682, doi:10.1002/rcm.3928


[file,path]=uigetfile({'*.mat'},'Open file aligned_footprints.mat');  % open file 'aligned_footprints.mat' with footprints 
load([path file]);

ii=1;                % 
for i=1:size(aligned_footprints,1)    % filtering rows with data in all columns
if sum(aligned_footprints(i,:))>0
aligned_footprints_filtered(ii,:)= aligned_footprints(i,:); 
ii=ii+1;  
end    
end


% Multidimensional scaling
D = pdist(aligned_footprints_filtered','euclidean'); % calculation of Euclidean distances between footprints
[Y,t] = cmdscale(D);                                 % multidimensional scaling
figure                                               % plotting of multidimensional scaling results
plot(Y(:,1),Y(:,2),'.','Color','white');
hold on 
for i=1:46
   text(Y(i,1)+0.02,Y(i,2),Names(i),'Color','black') 
end
axis([-100 900 -8 8]);
title('Multidimensional scaling of binary encoded footprints'); xlabel('Dimension 1'); ylabel('Dimension 2');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Generation of data presented on the Figure 6 in paper         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Correlation_matrix=corr(aligned_footprints_filtered,'Type','Spearman');   %  calculation of correlation between footprints

clear correlations
iii=1;
for i=10:17
     for ii=i+1:17
        correlations(iii)=Correlation_matrix(i,ii); iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']);
fprintf(['Mean value for correlations between footprints of endotheial cells - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of endotheial cells - ' num2str(std(correlations)) '\n']);

clear correlations  
iii=1;
for i=10:17
    for ii=1:8
        correlations(iii)=Correlation_matrix(i,ii); iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']);
fprintf(['Mean value for correlations between footprints of endotheial cells and cancer cells - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of endotheial cells and cancer cells - ' num2str(std(correlations)) '\n']);

clear correlations  
iii=1;
for i=10:17
    for ii=19:46
        correlations(iii)=Correlation_matrix(i,ii);
        iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']); 
fprintf(['Mean value for correlations between footprints of endotheial cells and fibroblasts - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of endotheial cells and fibroblasts - ' num2str(std(correlations)) '\n']);

clear correlations  
iii=1;
for i=1:8   
     for ii=i+1:8
        correlations(iii)=Correlation_matrix(i,ii); iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']);
fprintf(['Mean value for correlations between footprints of cancer cells - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of cancer cells - ' num2str(std(correlations)) '\n']);

clear correlations 
iii=1;
for i=19:46
     for ii=i+1:46
        correlations(iii)=Correlation_matrix(i,ii); iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']);
fprintf(['Mean value for correlations between footprints of fibroblasts - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of fibroblasts - ' num2str(std(correlations)) '\n']);

clear correlations  
iii=1;
for i=19:46
     for ii=1:8
        correlations(iii)=Correlation_matrix(i,ii); iii=iii+1;
    end
end
fprintf(['---------------------------' '\n']);
fprintf(['Mean value for correlations between footprints of fibroblasts and cancer cells - ' num2str(mean(correlations)) '\n']);
fprintf(['S.d. for correlations between footprints of fibroblasts and cancer cells - ' num2str(std(correlations)) '\n']);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%   for Endothelial cells (ECs) versus non-Endothelial cells (non-ECs)    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;  
clear correlations labels
for i=10:17 
for ii=i+1:17
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_1'; iii=iii+1;
end
end
n=iii-1;

for i=10:17
for ii=1:8
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2'; iii=iii+1;
end
end

for i=10:17
for ii=18:46
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2'; iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,correlations,'Class_2');
figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (ECs versus non-ECs)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%                 for Cancer cells versus non-Cancer cells                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;      
clear scores labels
for i=1:8  
for ii=i+1:8
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_1';
    iii=iii+1;
end
end
n=iii-1;

for i=1:8
for ii=10:46
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,correlations,'Class_2');
figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (Cancer cells versus non-Cancer cells)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%                 for Fibroblasts versus non-Fibroblasts                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;    
clear scores labels
for i=19:46  
for ii=i+1:46
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_1';
    iii=iii+1;
end
end
n=iii-1;

for i=19:46   
for ii=1:18
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,correlations,'Class_2');
figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (Fibroblasts versus non-Fibroblasts)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%      for IC96 drug-treated Cancer cells versus other Cancer cells       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[coefs,scores,variances,t2] = pca(aligned_footprints_filtered(:,[1 3:8])'); % PCA for MCF-7 cell footprints

iii=1;      
clear scores2 labels
for i=6:7  
for ii=1:5
    scores2(iii)=abs(scores(ii,1)-scores(i,1));
    labels(iii,:)='Class_1';
    iii=iii+1;
end
end
n=iii-1;

for i=1:5   
for ii=i+1:5
    scores2(iii)=abs(scores(ii,1)-scores(i,1));
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,scores2,'Class_2');
figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (IC96 drug-treated Cancer cells versus other Cancer cells)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%      for tumor-stimulated ECs versus other ECs                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[coefs,scores,variances,t2] = pca(aligned_footprints_filtered(:,[10:17])');  % PCA of EC footprints

iii=1;     
clear scores2 labels
for i=1:2  %
for ii=3:8
  scores2(iii)=abs(scores(ii,2)-scores(i,2));
  labels(iii,:)='Class_1';
  iii=iii+1;
end
end
n=iii-1;

for i=3:8    
for ii=i+1:8
    scores2(iii)=abs(scores(ii,2)-scores(i,2));
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,scores2,'Class_2');

figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (tumor-stimulated ECs versus other ECs)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%              for Adipose fibroblasts versus Skin fibroblasts            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;      
clear correlations labels
for i=19:22     
for ii=i+1:22
    scores(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='CaseCase';
    iii=iii+1;
end
end
n=iii-1;

for i=19:22
for ii=23:26
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Non_case';
    iii=iii+1;
end
end
n2=iii-1-n;

figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (Adipose fibroblasts versus Skin fibroblasts)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%              for Skin fibroblasts versus Dermal papilla fibroblasts     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;     
clear correlations labels
for i=23:26  
for ii=i+1:26
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_1';
    iii=iii+1;
end
end
n=iii-1;

for i=23:26 
for ii=29:46
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,correlations,'Class_2');

figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (Skin fibroblasts versus Dermal papilla fibroblasts)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Calculation of Sensitivity, Specificity, Accuracy and AUC        % 
%        for Adipose fibroblasts versus Dermal papilla fibroblasts        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

iii=1;      
clear correlations labels
for i=19:22              
for ii=i+1:22
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_1';
    iii=iii+1;
end
end
n=iii-1;

for i=19:22             
for ii=29:46
    correlations(iii)=Correlation_matrix(i,ii);
    labels(iii,:)='Class_2';
    iii=iii+1;
end
end
n2=iii-1-n;

[X1,Y1,T,AUC,OPTROCPT,SUBY,SUBYNAMES] = perfcurve(labels,correlations,'Class_2');

figure; plot(Y1*100,X1*100,'-r','LineWidth',2);  
title('ROC curve (Adipose fibroblasts versus Dermal papilla fibroblasts)'); ylabel('Sensitivity'); xlabel('1-Specificity');
[M1 M2]=max((1-Y1)+X1); sensitivity=1-Y1(M2); specificity=X1(M2); accuracy=((n*sensitivity)+(n2*specificity))/(iii-1);
text(60,30,['Sensitivity - ' num2str(sensitivity*100)]);
text(60,25,['Specificity - ' num2str(specificity*100)]);
text(60,20,['Accuracy - ' num2str(accuracy*100)]);
text(60,15,['Threshold - ' num2str(T(M2))]);
text(60,10,['AUC - ' num2str(1-AUC)]);

